Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1252)

Unified Diff: chrome/browser/io_thread.cc

Issue 6338002: net: Remove typedef net::URLRequestContext URLRequestContext; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: for real Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/io_thread.cc
diff --git a/chrome/browser/io_thread.cc b/chrome/browser/io_thread.cc
index 02801d20f9fd8e0060b6cd5785c6af89f7438679..83d229e7eee989fc183402ac05b0fe2c3502598e 100644
--- a/chrome/browser/io_thread.cc
+++ b/chrome/browser/io_thread.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -176,10 +176,10 @@ class LoggingNetworkChangeObserver
DISALLOW_COPY_AND_ASSIGN(LoggingNetworkChangeObserver);
};
-scoped_refptr<URLRequestContext>
+scoped_refptr<net::URLRequestContext>
ConstructProxyScriptFetcherContext(IOThread::Globals* globals,
net::NetLog* net_log) {
- scoped_refptr<URLRequestContext> context(new URLRequestContext);
+ scoped_refptr<net::URLRequestContext> context(new net::URLRequestContext);
context->set_net_log(net_log);
context->set_host_resolver(globals->host_resolver.get());
context->set_cert_verifier(globals->cert_verifier.get());
@@ -347,14 +347,14 @@ void IOThread::Init() {
&globals_->network_delegate,
net_log_));
- scoped_refptr<URLRequestContext> proxy_script_fetcher_context =
+ scoped_refptr<net::URLRequestContext> proxy_script_fetcher_context =
ConstructProxyScriptFetcherContext(globals_, net_log_);
globals_->proxy_script_fetcher_context = proxy_script_fetcher_context;
}
void IOThread::CleanUp() {
// Step 1: Kill all things that might be holding onto
- // net::URLRequest/URLRequestContexts.
+ // net::URLRequest/net::URLRequestContexts.
#if defined(USE_NSS)
net::ShutdownOCSP();
@@ -382,8 +382,8 @@ void IOThread::CleanUp() {
getter->ReleaseURLRequestContext();
}
// Step 2: Release objects that the URLRequestContext could have been pointing
// to.
// This must be reset before the ChromeNetLog is destroyed.
network_change_observer_.reset();
@@ -382,8 +382,8 @@ void IOThread::CleanUp() {
getter->ReleaseURLRequestContext();
}
- // Step 2: Release objects that the URLRequestContext could have been pointing
- // to.
+ // Step 2: Release objects that the net::URLRequestContext could have been
+ // pointing to.
// This must be reset before the ChromeNetLog is destroyed.
network_change_observer_.reset();

Powered by Google App Engine
This is Rietveld 408576698